@@ -10,7 +10,8 @@ require 'cucumber/term/ansicolor'
 
 module Cucumber
   class << self
-    attr_accessor :wants_to_quit, :use_legacy_autoloader
+    attr_accessor :wants_to_quit
+    attr_reader :use_legacy_autoloader
 
     def logger
       return @log if @log
@@ -23,5 +24,14 @@ module Cucumber
     def logger=(logger)
       @log = logger
     end
+
+    def use_legacy_autoloader=(value)
+      Cucumber.deprecate(
+        'This will be phased out of cucumber and should not be used. It is only there to support legacy systems',
+        '.use_legacy_autoloader',
+        '11.0.0'
+      )
+      @use_legacy_autoloader = value
+    end
   end
 end
