@@ -19,7 +19,7 @@ module Cucumber
     #
     # If the output is STDOUT (and not a file), there are bright colours to watch too.
     #
-    class Pretty # rubocop:disable Metrics/ClassLength
+    class Pretty
       include FileUtils
       include Console
       include Io
@@ -140,16 +140,20 @@ module Cucumber
         print_summary
       end
 
-      def attach(src, media_type)
+      def attach(src, media_type, filename)
         return unless media_type == 'text/x.cucumber.log+plain'
 
-        @test_step_output.push src
+        if filename
+          @test_step_output.push("#{filename}: #{src}")
+        else
+          @test_step_output.push(src)
+        end
       end
 
       private
 
       def find_exception_to_be_printed(result)
-        return nil if result.ok?(options[:strict])
+        return nil if result.ok?(strict: options[:strict])
 
         result = result.with_filtered_backtrace(Cucumber::Formatter::BacktraceFilter)
         exception = result.failed? ? result.exception : result
@@ -391,7 +395,7 @@ module Cucumber
         end
       end
 
-      def print_outline_data(scenario_outline) # rubocop:disable Metrics/AbcSize
+      def print_outline_data(scenario_outline)
         print_comments(scenario_outline.location.line, 2)
         print_tags(scenario_outline.tags, 2)
         @source_indent = calculate_source_indent_for_ast_node(scenario_outline) if options[:source]
